# encoding: utf-8
"""
@author: yizhao
@file: __init__.py.py
@time: 2022/8/29 10:03
@desc:
"""
import os
import json
import nacos

SERVER_ENDPOINT = "nacos.meetwhale.com"
DEFAULT_GROUP = "DEFAULT"

nacos_config = os.getenv("NACOS_CONFIG")
if nacos_config is None:
    raise Exception("Please set the env variable of NACOS_CONFIG")
nacos_config = json.loads(nacos_config)
namespace = nacos_config.get('client_conf').get('NamespaceId')

nacos_client = nacos.NacosClient(SERVER_ENDPOINT, namespace=namespace)
frame_client = nacos.NacosClient(SERVER_ENDPOINT, namespace=f'frameworks-{namespace}')



# encoding: utf-8
"""
@author: yizhao
@file: test_config.py
@time: 2022/8/29 10:02
@desc:
"""
import unittest
from src import config


class TestNacos(unittest.TestCase):
    def test_get_config(self):
        configs = config.get_config("aml-video-task")
        pg_configs = config.get_pg_config("aml-video-task")
        print(configs)
        print(pg_configs)


# encoding: utf-8
"""
@author: yizhao
@file: setup.py
@time: 2022/8/29 10:49
@desc:
"""
# encoding: utf-8
from setuptools import setup, find_packages, find_namespace_packages


# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='whale-nacos',
    version="0.4.2",
    author="Joey",
    author_email='yizhao@whale.im',
    description='whale nacos sdk',
    long_description_content_type='text/markdown',
    long_description=long_description,
    packages=['whnacos'],
    include_package_data=True,
    install_requires=[
        "nacos-sdk-python",
        "grpcio"
    ],
    python_requires='>=3.5',
    dependency_link=[
        "https://files.pythonhosted.org/packages/90/72/9e7625b9041f249af86a2903090e94959d8fd56b7cf37d3a0cef6039168f/grpcio-1.48.1-cp310-cp310-macosx_10_10_x86_64.whl"
    ],
    package_dir={'whnacos': 'src'}

)



# encoding: utf-8
"""
@author: yizhao
@file: whnacos.py
@time: 2022/8/29 09:53
@desc:
"""
import json
import nacos
from . import nacos_client as client
from . import frame_client
from . import DEFAULT_GROUP


def get_config(service_name: str, group=DEFAULT_GROUP):
    """
    get nacos config by register service name
    :param service_name: service name
    :param group: group name
    :return:
    """
    conf = client.get_config(service_name, group)
    if conf is None:
        raise Exception('failed to get pg configs')

    return json.loads(conf)


def get_pg_config(service_name="", group=DEFAULT_GROUP):
    """
    get postgres configs via frameworks
    :param service_name:
    :param group:
    :return:
    """
    framework_config = get_framework_pg_config()
    if service_name == "":
        return framework_config

    pg_conf = client.get_config(f"{service_name}.pg-config", group)

    if pg_conf is None:
        raise Exception('failed to get pg configs')
    pg_conf = json.loads(pg_conf)
    return {**framework_config, **pg_conf}


def get_framework_pg_config():

    framework_conf = frame_client.get_config(f"pg-config", DEFAULT_GROUP)
    if framework_conf is None:
        raise Exception("failed to get frameworks configs")
    return json.loads(framework_conf)


